webbpsf\_ext.opds.OTE\_WFE\_Drift\_Model
========================================

.. currentmodule:: webbpsf_ext.opds

.. autoclass:: OTE_WFE_Drift_Model
   :members:
   :inherited-members:
   :show-inheritance:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~OTE_WFE_Drift_Model.__init__
      ~OTE_WFE_Drift_Model.apply_frill_drift
      ~OTE_WFE_Drift_Model.apply_iec_drift
      ~OTE_WFE_Drift_Model.as_fits
      ~OTE_WFE_Drift_Model.calc_rms
      ~OTE_WFE_Drift_Model.copy
      ~OTE_WFE_Drift_Model.display
      ~OTE_WFE_Drift_Model.display_opd
      ~OTE_WFE_Drift_Model.estimated_Strehl
      ~OTE_WFE_Drift_Model.evolve_dopd
      ~OTE_WFE_Drift_Model.gen_delta_opds
      ~OTE_WFE_Drift_Model.gen_frill_drift
      ~OTE_WFE_Drift_Model.gen_iec_series
      ~OTE_WFE_Drift_Model.gen_thermal_drift
      ~OTE_WFE_Drift_Model.get_opd
      ~OTE_WFE_Drift_Model.get_phasor
      ~OTE_WFE_Drift_Model.get_transmission
      ~OTE_WFE_Drift_Model.header_keywords
      ~OTE_WFE_Drift_Model.interp_dopds
      ~OTE_WFE_Drift_Model.label_seg
      ~OTE_WFE_Drift_Model.move_global_zernikes
      ~OTE_WFE_Drift_Model.move_seg_global
      ~OTE_WFE_Drift_Model.move_seg_local
      ~OTE_WFE_Drift_Model.move_sm_local
      ~OTE_WFE_Drift_Model.move_sur
      ~OTE_WFE_Drift_Model.opds_as_hdul
      ~OTE_WFE_Drift_Model.print_state
      ~OTE_WFE_Drift_Model.ptv
      ~OTE_WFE_Drift_Model.reset
      ~OTE_WFE_Drift_Model.rms
      ~OTE_WFE_Drift_Model.slew_pos_averages
      ~OTE_WFE_Drift_Model.slew_scaling
      ~OTE_WFE_Drift_Model.thermal_slew
      ~OTE_WFE_Drift_Model.update_opd
      ~OTE_WFE_Drift_Model.writeto
      ~OTE_WFE_Drift_Model.zern_seg
      ~OTE_WFE_Drift_Model.zero
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~OTE_WFE_Drift_Model.pupil_diam
      ~OTE_WFE_Drift_Model.shape
      ~OTE_WFE_Drift_Model.name
   
   